==> tutti-ui-swing-2.5-sources.jar: fr/ifremer/tutti/ui/swing/content/referential/ManageTemporaryReferentialUIHandler.java <==
package fr.ifremer.tutti.ui.swing.content.referential;

/*
 * #%L
 * Tutti :: UI
 * $Id: ManageTemporaryReferentialUIHandler.java 762 2013-04-10 16:53:38Z kmorin $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-2.5/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/content/referential/ManageTemporaryReferentialUIHandler.java $
 * %%
 * Copyright (C) 2012 - 2013 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import fr.ifremer.tutti.service.PersistenceService;
import fr.ifremer.tutti.ui.swing.TuttiUIContext;
import fr.ifremer.tutti.ui.swing.util.AbstractTuttiUIHandler;
import jaxx.runtime.validator.swing.SwingValidator;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import javax.swing.JComponent;

/**
 * @author tchemit <chemit@codelutin.com>
 * @since 1.0
 */
public class ManageTemporaryReferentialUIHandler extends AbstractTuttiUIHandler<TuttiUIContext, ManageTemporaryReferentialUI> {

    /** Logger. */
    private static final Log log =
            LogFactory.getLog(ManageTemporaryReferentialUIHandler.class);

    protected JComponent currentBody;

    protected final PersistenceService persistenceService;

    protected ManageTemporaryReferentialUIHandler(TuttiUIContext context,
                                                  ManageTemporaryReferentialUI ui) {
        super(context, ui);
        this.persistenceService = context.getPersistenceService();
    }

    //------------------------------------------------------------------------//
    //-- AbstractTuttiUIHandler methods                                     --//
    //------------------------------------------------------------------------//

    @Override
    public void beforeInitUI() {
    }

    @Override
    public void afterInitUI() {

        initUI(ui);
    }

    @Override
    protected JComponent getComponentToFocus() {
        return null;
    }

    @Override
    public void onCloseUI() {
        if (log.isDebugEnabled()) {
            log.debug("closing: " + ui);
        }
    }

    @Override
    public SwingValidator<TuttiUIContext> getValidator() {
        return null;
    }
}

==> tutti-ui-swing-2.5.1-sources.jar: fr/ifremer/tutti/ui/swing/content/referential/ManageTemporaryReferentialUIHandler.java <==
package fr.ifremer.tutti.ui.swing.content.referential;

/*
 * #%L
 * Tutti :: UI
 * $Id: ManageTemporaryReferentialUIHandler.java 762 2013-04-10 16:53:38Z kmorin $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-2.5.1/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/content/referential/ManageTemporaryReferentialUIHandler.java $
 * %%
 * Copyright (C) 2012 - 2013 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import fr.ifremer.tutti.service.PersistenceService;
import fr.ifremer.tutti.ui.swing.TuttiUIContext;
import fr.ifremer.tutti.ui.swing.util.AbstractTuttiUIHandler;
import jaxx.runtime.validator.swing.SwingValidator;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import javax.swing.JComponent;

/**
 * @author tchemit <chemit@codelutin.com>
 * @since 1.0
 */
public class ManageTemporaryReferentialUIHandler extends AbstractTuttiUIHandler<TuttiUIContext, ManageTemporaryReferentialUI> {

    /** Logger. */
    private static final Log log =
            LogFactory.getLog(ManageTemporaryReferentialUIHandler.class);

    protected JComponent currentBody;

    protected final PersistenceService persistenceService;

    protected ManageTemporaryReferentialUIHandler(TuttiUIContext context,
                                                  ManageTemporaryReferentialUI ui) {
        super(context, ui);
        this.persistenceService = context.getPersistenceService();
    }

    //------------------------------------------------------------------------//
    //-- AbstractTuttiUIHandler methods                                     --//
    //------------------------------------------------------------------------//

    @Override
    public void beforeInitUI() {
    }

    @Override
    public void afterInitUI() {

        initUI(ui);
    }

    @Override
    protected JComponent getComponentToFocus() {
        return null;
    }

    @Override
    public void onCloseUI() {
        if (log.isDebugEnabled()) {
            log.debug("closing: " + ui);
        }
    }

    @Override
    public SwingValidator<TuttiUIContext> getValidator() {
        return null;
    }
}
